@@ -23,3 +23,12 @@ module Infix = struct
 end
 
 include Infix
+
+let is_uppercase_ascii c = c > '\064' && c < '\091'
+let is_lowercase_ascii c = c > '\096' && c < '\123'
+
+let is_letter_ascii c =
+  (is_lowercase_ascii [@inlined]) c || (is_uppercase_ascii [@inlined]) c
+
+let is_digit_ascii c = c > '\047' && c < '\058'
+let is_whitespace_ascii c = c = '\032' || (c > '\008' && c < '\014')
