@@ -475,7 +475,7 @@ let for_all p v =
 
 let member ~eq x v = exists (eq x) v
 
-let find_internal_ p v =
+let find_internal_i_ p v =
   let n = v.size in
   let rec check i =
     if i = n then
@@ -483,15 +483,18 @@ let find_internal_ p v =
     else (
       let x = v.vec.(i) in
       if p x then
-        x
+        i, x
       else
         check (i + 1)
     )
   in
   check 0
 
-let find_exn p v = try find_internal_ p v with Not_found -> raise Not_found
-let find p v = try Some (find_internal_ p v) with Not_found -> None
+let find_exn p v =
+  try snd (find_internal_i_ p v) with Not_found -> raise Not_found
+
+let find p v = try Some (snd @@ find_internal_i_ p v) with Not_found -> None
+let findi p v = try Some (find_internal_i_ p v) with Not_found -> None
 
 let find_map f v =
   let n = v.size in
