@@ -21,3 +21,15 @@ true
 t @@ fun () -> CCFun.((succ %> string_of_int) 2 = "3");;
 t @@ fun () -> CCFun.((( * ) 3 % succ) 5 = 18);;
 t @@ fun () -> CCFun.(succ @@ ( * ) 2 @@ pred @@ 3 = 5)
+
+let find_array arr x =
+  let@ return = with_return in
+  for i = 0 to Array.length arr - 1 do
+    if arr.(i) = x then return i
+  done;
+  -1
+;;
+
+eq 1 @@ find_array [| "a"; "b"; "c" |] "b";;
+eq 2 @@ find_array [| "a"; "b"; "c" |] "c";;
+eq (-1) @@ find_array [| "a"; "b"; "c" |] "hello"
